# from fcolors import fg
# from fcolors import bg
# from fcolors import bold
# from fcolors import uline
# from fcolors import fg_hi
# from fcolors import bg_hi
# from fcolors import all_hi
# from fcolors import bold_hi
# from fcolors import reset
# from fcolors import Color
# from fcolors import esc

# __all__ = [
#     'fg',
#     'bg',
#     'bold',
#     'uline',
#     'fg_hi',
#     'bg_hi',
#     'fb_hi',
#     'reset',
#     'Color',
#     'esc',
# ]

